@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # **********************************************************************
 #
-# Copyright (c) 2003-2008 ZeroC, Inc. All rights reserved.
+# Copyright (c) 2003-2009 ZeroC, Inc. All rights reserved.
 #
 # This copy of Ice is licensed to you under the terms described in the
 # ICE_LICENSE file included in this distribution.
@@ -10,8 +10,8 @@
 
 import os, sys, imp
 
-sys.path.append(os.path.join(os.path.dirname(__file__), "config"))
-import TestUtil
+sys.path.append(os.path.join(os.path.dirname(__file__)))
+from scripts import *
 
 testGroups = []
 
