@@ -1,6 +1,6 @@
 // **********************************************************************
 //
-// Copyright (c) 2003-2008 ZeroC, Inc. All rights reserved.
+// Copyright (c) 2003-2009 ZeroC, Inc. All rights reserved.
 //
 // This copy of Ice is licensed to you under the terms described in the
 // ICE_LICENSE file included in this distribution.
@@ -705,13 +705,6 @@ public:
     destroy()
     {
     }
-    
-    void
-    install(const Ice::CommunicatorPtr& communicator)
-    {
-        communicator->addObjectFactory(this, "::Class1");
-        communicator->addObjectFactory(this, "::Class2");
-    }
 };
 typedef IceUtil::Handle<MyFactory> MyFactoryPtr;
 
@@ -787,8 +780,7 @@ TestApp::run(int argc, char* argv[])
 #endif
 
     MyFactoryPtr factory = new MyFactory();
-    factory->install(communicator());
-    
+
     cout <<"Struct1ObjectMap" << endl;
     Struct1ObjectMapTest();
 
