@@ -1,6 +1,6 @@
 // **********************************************************************
 //
-// Copyright (c) 2003-2008 ZeroC, Inc. All rights reserved.
+// Copyright (c) 2003-2009 ZeroC, Inc. All rights reserved.
 //
 // This copy of Ice is licensed to you under the terms described in the
 // ICE_LICENSE file included in this distribution.
@@ -37,7 +37,7 @@ CallbackI::initiateCallback(const CallbackReceiverPrx& proxy, const Ice::Current
     cout << "initiating callback to: " << current.adapter->getCommunicator()->proxyToString(proxy) << endl;
     try
     {
-        proxy->callback(current.ctx);
+        proxy->callback();
     }
     catch(const Ice::Exception& ex)
     {
