@@ -1,6 +1,6 @@
 // **********************************************************************
 //
-// Copyright (c) 2003-2008 ZeroC, Inc. All rights reserved.
+// Copyright (c) 2003-2009 ZeroC, Inc. All rights reserved.
 //
 // This copy of Ice is licensed to you under the terms described in the
 // ICE_LICENSE file included in this distribution.
@@ -14,7 +14,7 @@
 using namespace std;
 
 void
-HelloI::sayHello(int delay, const Ice::Current&) const
+HelloI::sayHello(int delay, const Ice::Current&)
 {
     if(delay != 0)
     {
