@@ -1,6 +1,6 @@
 // **********************************************************************
 //
-// Copyright (c) 2003-2008 ZeroC, Inc. All rights reserved.
+// Copyright (c) 2003-2009 ZeroC, Inc. All rights reserved.
 //
 // This copy of Ice is licensed to you under the terms described in the
 // ICE_LICENSE file included in this distribution.
@@ -16,12 +16,12 @@ using namespace std;
 Ice::ObjectPtr
 ObjectFactory::create(const string& type)
 {
-    if(type == "::Demo::Printer")
+    if(type == Demo::Printer::ice_staticId())
     {
         return new PrinterI;
     }
 
-    if(type == "::Demo::DerivedPrinter")
+    if(type == Demo::DerivedPrinter::ice_staticId())
     {
         return new DerivedPrinterI;
     }
