@@ -1,6 +1,6 @@
 // **********************************************************************
 //
-// Copyright (c) 2003-2008 ZeroC, Inc. All rights reserved.
+// Copyright (c) 2003-2009 ZeroC, Inc. All rights reserved.
 //
 // This copy of Ice is licensed to you under the terms described in the
 // ICE_LICENSE file included in this distribution.
@@ -17,7 +17,7 @@ HelloI::HelloI(const string& name) : _name(name)
 }
 
 std::string
-HelloI::getGreeting(const Ice::Current&) const
+HelloI::getGreeting(const Ice::Current&)
 {
     return _name + " says Hello World!";
 }
