@@ -1,6 +1,6 @@
 // **********************************************************************
 //
-// Copyright (c) 2003-2008 ZeroC, Inc. All rights reserved.
+// Copyright (c) 2003-2009 ZeroC, Inc. All rights reserved.
 //
 // This copy of Ice is licensed to you under the terms described in the
 // ICE_LICENSE file included in this distribution.
@@ -18,7 +18,7 @@ public:
 
     HelloI(const std::string&);
 
-    virtual void sayHello(const Ice::Current&) const;
+    virtual void sayHello(const Ice::Current&);
 
 private:
     
