@@ -1,6 +1,6 @@
 // **********************************************************************
 //
-// Copyright (c) 2003-2008 ZeroC, Inc. All rights reserved.
+// Copyright (c) 2003-2009 ZeroC, Inc. All rights reserved.
 //
 // This copy of Ice is licensed to you under the terms described in the
 // ICE_LICENSE file included in this distribution.
@@ -30,7 +30,9 @@ public:
         // Create the root directory.
         //
         DirectoryIPtr root = new DirectoryI;
-        root->activate(adapter);
+        Ice::Identity id;
+        id.name = "RootDir";
+        adapter->add(root, id);
 
         // All objects are created, allow client requests now.
         //
