@@ -1,6 +1,6 @@
 // **********************************************************************
 //
-// Copyright (c) 2003-2008 ZeroC, Inc. All rights reserved.
+// Copyright (c) 2003-2009 ZeroC, Inc. All rights reserved.
 //
 // This copy of Ice is licensed to you under the terms described in the
 // ICE_LICENSE file included in this distribution.
@@ -200,6 +200,7 @@ public:
             delete oldEncaps;
         }
     }
+    void endWriteEncapsChecked(); // Used by public stream API.
 
     void startReadEncaps()
     {
@@ -298,6 +299,7 @@ public:
         }
         i += 2;
     }
+    void endReadEncapsChecked(); // Used by public stream API.
 
     Ice::Int getReadEncapsSize();
     void skipEncaps();
